using System;
using System.Data;
using System.Collections;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.UIControls;

public partial class CMSFormControls_LiveSelectors_TagSelector : CMSLiveModalPage
{
    #region "Variables"

    private int groupId = 0;
    private string textBoxId = null;
    private string oldTags = null;
    private Hashtable selectedTags = null;

    #endregion


    #region "Page Events"

    protected void Page_Load(object sender, EventArgs e)
    {
        // Register jQuery
        ScriptHelper.RegisterJQuery(Page);

        // Get group Id
        groupId = QueryHelper.GetInteger("group", 0);

        // Get id of the base selector textbox
        textBoxId = QueryHelper.GetString("textbox", "");

        // Get selected tags
        oldTags = QueryHelper.GetString("tags", "");
        selectedTags = TagHelper.GetTags(oldTags);

        // Setup UniGrid
        gridElem.ZeroRowsText = ResHelper.GetString("tags.tagselector.noold");
        gridElem.GridView.ShowHeader = false;
        gridElem.OnDataReload += gridElem_OnDataReload;
        gridElem.OnExternalDataBound += gridElem_OnExternalDataBound;

        // Register helper string functions
        ScriptHelper.RegisterClientScriptBlock(Page, typeof(string), "HelperFunction", ScriptHelper.GetScript(
            "function trim(strText, str) { var re1 = new RegExp('^(' + str + ')*');  var re2 = new RegExp('(' + str + ')*$'); return strText.replace(re1, '').replace(re2, ''); } "));

        // Register script for managing the selection
        ScriptHelper.RegisterClientScriptBlock(Page, typeof(string), "ChangeSelectionScript", ScriptHelper.GetScript(
            "function changeSelection(chkName) { \n" +
            "  var hdn = document.getElementById('" + hdnValues.ClientID + "'); \n" +
            "  var chk = document.getElementById(chkName); \n" +
            "  if ((hdn != null) && (chk != null)) { \n" +
            "    if (chk.checked) { \n" +
            "       hdn.value = trim(hdn.value + ',' + chk.value, ',');\n" +
            "    } else { \n" +
            "       var re = new RegExp(',' + chk.value + ','); \n" +
            "       var text = ',' + hdn.value + ','; \n" +
            "       hdn.value = trim(text.replace(re, ','), ',');\n" +
            "    } \n" +
            "   \n" +
            "  } \n" +
            "} \n"));

        // Page title
        CurrentMaster.Title.TitleImage = ResolveUrl(GetImageUrl("Objects/CMS_TagGroup/object.png", true));
        CurrentMaster.Title.TitleText = ResHelper.GetString("tags.tagselector.title");

        btnOk.Click += btnOk_Click;
    }


    protected void btnOk_Click(object sender, EventArgs e)
    {
        string retval = "";

        // Append tags which are not in DB
        foreach (object o in selectedTags.Values)
        {
            string tagName = ValidationHelper.GetString(o, "");
            retval = (retval + ", " + tagName);
        }

        // Append selected tags which are already in DB
        if (gridElem.SelectedItems.Count > 0)
        {
            ArrayList tags = gridElem.SelectedItems;
            tags.Sort();
            foreach (string tagName in tags)
            {
                if (tagName.Contains(" "))
                {
                    retval = (retval + ", \"" + tagName + "\"");
                }
                else
                {
                    retval = (retval + ", " + tagName);
                }
            }
        }

        // Remove
        if (retval != "")
        {
            retval = retval.Substring(2);
        }

        ltlScript.Text = ScriptHelper.GetScript("wopener.setTagsToTextBox('" + textBoxId + "', " + ScriptHelper.GetString(retval) + "); window.close();");
    }

    #endregion


    #region "UniGrid Events"

    protected DataSet gridElem_OnDataReload(string completeWhere, int currentTopN)
    {
        string where = "(TagGroupID = " + groupId + ")";
        if (!String.IsNullOrEmpty(completeWhere))
        {
            where += " AND (" + completeWhere + ")";
        }

        DataSet ds = TagInfoProvider.GetTags(where, "TagName", currentTopN, "TagID,TagName,TagCount");
        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            ArrayList selection = new ArrayList();
            // Remove old tags from selected tags
            foreach (DataRow dr in ds.Tables[0].Rows)
            {
                string tagName = dr["TagName"].ToString();
                if (selectedTags.Contains(tagName) || selectedTags.Contains(tagName.ToLower()) || selectedTags.Contains("\"" + tagName + "\"") || selectedTags.Contains("\"" + tagName.ToLower() + "\""))
                {
                    selection.Add(tagName);

                    selectedTags.Remove(tagName);
                    selectedTags.Remove(tagName.ToLower());
                    selectedTags.Remove("\"" + tagName + "\"");
                    selectedTags.Remove("\"" + tagName.ToLower() + "\"");
                }
            }
            if (!UrlHelper.IsPostback())
            {
                gridElem.SelectedItems = selection;
            }
        }

        return ds;
    }


    protected object gridElem_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        if (sourceName.ToLower() == "tagname")
        {
            DataRowView drv = (DataRowView)parameter;
            string tagName = ValidationHelper.GetString(drv["TagName"], "");
            string tagId = ValidationHelper.GetString(drv["TagID"], "");
            if ((tagName != "") && (tagName != tagId))
            {
                string tagCount = ValidationHelper.GetString(drv["TagCount"], "");
                string tagText = HTMLHelper.HTMLEncode(tagName) + " (" + tagCount + ")";

                // Create link with onclick envent which call onclick event of checkbox in previous column
                return "<a href=\"#\" onclick=\"try { $j(this.parentNode).prev().find('input').click(); } catch (e) {} return false;\">" + tagText + "</a>";
            }
        }
        return "";
    }

    #endregion
}